@@ -1,7 +1,6 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
-from trytond.transaction import Transaction
 
 
 class Country(ModelSQL, ModelView):
@@ -9,8 +8,8 @@ class Country(ModelSQL, ModelView):
     _name = 'country.country'
     _description = __doc__
     name = fields.Char('Name', required=True, translate=True,
-           help='The full name of the country.', select=1)
-    code = fields.Char('Code', size=2, select=1,
+           help='The full name of the country.', select=True)
+    code = fields.Char('Code', size=2, select=True,
            help='The ISO country code in two chars.\n'
            'You can use this field for quick search.', required=True)
     subdivisions = fields.One2Many('country.subdivision',
@@ -27,10 +26,10 @@ class Country(ModelSQL, ModelView):
         self._order.insert(0, ('name', 'ASC'))
 
     def search_rec_name(self, name, clause):
-        ids = self.search([('code',) + tuple(clause[1:])], limit=1)
+        ids = self.search([('code',) + clause[1:]], limit=1)
         if ids:
-            return [('code',) + tuple(clause[1:])]
-        return [(self._rec_name,) + tuple(clause[1:])]
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def create(self, vals):
         if 'code' in vals and vals['code']:
@@ -52,9 +51,9 @@ class Subdivision(ModelSQL, ModelView):
     _name = 'country.subdivision'
     _description = __doc__
     country = fields.Many2One('country.country', 'Country',
-            required=True, select=1)
-    name = fields.Char('Name', required=True, select=1, translate=True)
-    code = fields.Char('Code', required=True, select=1)
+            required=True, select=True)
+    name = fields.Char('Name', required=True, select=True, translate=True)
+    code = fields.Char('Code', required=True, select=True)
     type = fields.Selection([
         ('administration', 'Administration'),
         ('administrative area', 'Administrative area'),
@@ -114,7 +113,8 @@ class Subdivision(ModelSQL, ModelView):
         ('oblast', 'Oblast'),
         ('outlying area', 'Outlying area'),
         ('overseas region/department', 'Overseas region/department'),
-        ('overseas territorial collectivity', 'Overseas territorial collectivity'),
+        ('overseas territorial collectivity',
+            'Overseas territorial collectivity'),
         ('parish', 'Parish'),
         ('prefecture', 'Prefecture'),
         ('principality', 'Principality'),
@@ -144,10 +144,10 @@ class Subdivision(ModelSQL, ModelView):
         self._order.insert(0, ('code', 'ASC'))
 
     def search_rec_name(self, name, clause):
-        ids = self.search([('code',) + tuple(clause[1:])], limit=1)
+        ids = self.search([('code',) + clause[1:]], limit=1)
         if ids:
-            return [('code',) + tuple(clause[1:])]
-        return [(self._rec_name,) + tuple(clause[1:])]
+            return [('code',) + clause[1:]]
+        return [(self._rec_name,) + clause[1:]]
 
     def create(self, vals):
         if 'code' in vals and vals['code']:
